import crypto from "crypto";
import bcrypt from "bcrypt";
import { v4 as uuidv4 } from "uuid";
import { Response } from "express";
import Session from "../models/session";
import { DEFAULT_SESSION_EXPIRY } from "./constants";

export async function matchPassword(decodedPassword: string, password: string) {
  return await bcrypt.compare(decodedPassword, password);
}

export async function hashPassword(password: string) {
  return await bcrypt.hash(password, 10);
}

export function decodeBase64(value: string) {
  return Buffer.from(value, "base64").toString("utf-8");
}

export function newUserId() {
  return uuidv4();
}

export function newUserSession() {
  return crypto.randomBytes(32).toString("hex");
}

export async function saveSession(
  res: Response,
  userId: string,
  username: string
) {
  try {
    const userSession = newUserSession();

    await Session.create({
      user_id: userId,
      session_id: userSession,
      expires: new Date(Date.now() + DEFAULT_SESSION_EXPIRY),
    });

    res.status(200).json({
      XAuthorization: userSession,
      Username: username,
    });
  } catch (err) {
    console.log(err);
    res.status(500).send({ err: "invalid request" });
  }
}
